@@ -1,3 +1,5 @@
 from graph_algo_vis.bfs_traversal import BFS
 from graph_algo_vis.dfs_traversal import DFS
-from graph_algo_vis.topological_sort import Top_Sort
\ No newline at end of file
+from graph_algo_vis.topological_sort import Top_Sort
+from graph_algo_vis.primsMST import Prims
+from graph_algo_vis.kruskalsMST import Kruskals
\ No newline at end of file
